# Ideas

- TODO: Make all editors multi-session. Store content on server => backup.
  Allows having multiple sessions open, e.g. on laptop and desktop.

- TODO: Allow teacher to select a student session to display and interact with
  their editor content. Allows live-correcting a student's exercise while
  projecting to the class.

- TODO: Render as pdf with solutions (open dropdowns).

- TODO: Make the `name` attribute in graphviz work. This requires a fix in
  Sphinx.

- TODO: Add a presentation mode that removes the left and right margins.

- TODO: Customize sidebars in CSS to allow using them to display an image next
  to some text or a block of code.

- TODO: Allow generating graphs with matplotlib
  <https://matplotlib.org/sampledoc/extensions.html>.

- TODO: Make `{ref}` against a `{num}` show its expanded content.
